import * as ec2 from '@aws-cdk/aws-ec2';
import { Construct, Resource, ResourceProps, Stack, Duration } from '@aws-cdk/core';
import * as iam from '@aws-cdk/aws-iam';
/**
 *
 */
export declare class VpcProvider extends Stack {
    /**
     *
     */
    static getOrCreate(scope: Construct): ec2.IVpc;
}
/**
 *
 */
export declare enum BlockDuration {
    /**
     *
     */
    ONE_HOUR = 60,
    /**
     *
     */
    TWO_HOURS = 120,
    /**
     *
     */
    THREE_HOURS = 180,
    /**
     *
     */
    FOUR_HOURS = 240,
    /**
     *
     */
    FIVE_HOURS = 300,
    /**
     *
     */
    SIX_HOURS = 360,
    /**
     *
     */
    NONE = 0
}
/**
 * Whether the worker nodes should support GPU or just standard instances.
 */
export declare enum NodeType {
    /**
     * Standard instances.
     */
    STANDARD = "Standard",
    /**
     * GPU instances.
     */
    GPU = "GPU",
    /**
     * Inferentia instances.
     */
    INFERENTIA = "INFERENTIA",
    /**
     * ARM instances.
     */
    ARM = "ARM"
}
/**
 *
 */
export declare enum InstanceInterruptionBehavior {
    /**
     *
     */
    HIBERNATE = "hibernate",
    /**
     *
     */
    STOP = "stop",
    /**
     *
     */
    TERMINATE = "terminate"
}
/**
 *
 */
export interface SpotFleetLaunchTemplateConfig {
    /**
     *
     */
    readonly spotfleet: SpotFleet;
    /**
     *
     */
    readonly launchTemplate: ILaunchtemplate;
}
/**
 *
 */
export interface ILaunchtemplate {
    /**
     *
     */
    bind(spotfleet: SpotFleet): SpotFleetLaunchTemplateConfig;
}
/**
 *
 */
export declare class LaunchTemplate implements ILaunchtemplate {
    /**
     *
     */
    bind(spotfleet: SpotFleet): SpotFleetLaunchTemplateConfig;
}
/**
 *
 */
export interface BaseSpotFleetProps extends ResourceProps {
    /**
     * VPC for the spot fleet.
     *
     * @default - new VPC will be created
     */
    readonly vpc?: ec2.IVpc;
    /**
     * default EC2 instance type.
     *
     * @default - t3.large
     */
    readonly defaultInstanceType?: ec2.InstanceType;
    /**
     * reservce the spot instance as spot block with defined duration.
     *
     * @default - BlockDuration.ONE_HOUR
     */
    readonly blockDuration?: BlockDuration;
    /**
     * The behavior when a Spot Instance is interrupted.
     *
     * @default - InstanceInterruptionBehavior.TERMINATE
     */
    readonly instanceInterruptionBehavior?: InstanceInterruptionBehavior;
    /**
     * IAM role for the spot instance.
     */
    readonly instanceRole?: iam.Role;
    /**
     * number of the target capacity.
     *
     * @default - 1
     */
    readonly targetCapacity?: number;
    /**
     * the time when the spot fleet allocation starts.
     *
     * @default - no expiration
     */
    readonly validFrom?: string;
    /**
     * the time when the spot fleet allocation expires.
     *
     * @default - no expiration
     */
    readonly validUntil?: string;
    /**
     * terminate the instance when the allocation is expired.
     *
     * @default - true
     */
    readonly terminateInstancesWithExpiration?: boolean;
    /**
     * custom AMI ID.
     *
     * @default - The latest Amaozn Linux 2 AMI ID
     */
    readonly customAmiId?: string;
    /**
     * VPC subnet for the spot fleet.
     *
     * @default - public subnet
     */
    readonly vpcSubnet?: ec2.SubnetSelection;
    /**
     * SSH key name.
     *
     * @default - no ssh key will be assigned
     */
    readonly keyName?: string;
    /**
     * Additional commands for user data.
     *
     * @default - no additional user data
     */
    readonly additionalUserData?: string[];
}
/**
 *
 */
export interface SpotFleetProps extends BaseSpotFleetProps {
    /**
     * Launch template for the spot fleet.
     */
    readonly launchTemplate?: ILaunchtemplate;
    /**
     * Allocation ID for your existing Elastic IP Address.
     *
     * @defalt new EIP and its association will be created for the first instance in this spot fleet
     */
    readonly eipAllocationId?: string;
}
/**
 *
 */
export declare class SpotFleet extends Resource {
    /**
     *
     */
    readonly instanceRole: iam.IRole;
    /**
     *
     */
    readonly defaultInstanceType: ec2.InstanceType;
    /**
     *
     */
    readonly targetCapacity?: number;
    /**
     *
     */
    readonly spotFleetId: string;
    /**
     *
     */
    readonly launchTemplate: ILaunchtemplate;
    /**
     *
     */
    readonly vpc: ec2.IVpc;
    /**
     * the first instance id in this fleet.
     */
    readonly instanceId: string;
    /**
     * instance type of the first instance in this fleet.
     */
    readonly instanceType: string;
    /**
     * SpotFleetRequestId for this spot fleet.
     */
    readonly spotFleetRequestId: string;
    /**
     * The time when the the fleet allocation will expire
     */
    private validUntil?;
    /**
     * The default security group of the instance, which only allows TCP 22 SSH ingress rule.
     */
    readonly defaultSecurityGroup: ec2.ISecurityGroup;
    /**
     *
     */
    constructor(scope: Construct, id: string, props?: SpotFleetProps);
    /**
     *
     */
    expireAfter(duration: Duration): void;
}
